Documentation
¶
Index ¶
Constants ¶
const ( // ReconnectSleep determines the length of time to wait between reconnect attempts to dProxy ReconnectSleep = time.Second * 5 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AttachedStream ¶
type Client ¶
type Client struct {
*Config
Client protos.VCServiceClient
Conn *grpc.ClientConn
EventsCh chan *protos.VCEvent
AttachedStreams map[string]*AttachedStream
AttachedStreamsMutex *sync.RWMutex
// contains filtered or unexported fields
}
func (*Client) AttachStream ¶
func (c *Client) AttachStream(id string) *AttachedStream
AttachStream adds a vc-service event listener to the AttachedStreams map which will receive a copy of all VCEvent messages
func (*Client) DetachStream ¶
DetachStream removes a vc-service event listener from AttachedStreams map
type IVCService ¶
type IVCService interface {
AttachStream(id string) *AttachedStream
DetachStream(id string)
}
func New ¶
func New(cfg *Config) (IVCService, error)
New validates CLI options and returns a new Client struct
Click to show internal directories.
Click to hide internal directories.